using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Westwind.AspNetCore.LiveReload;
using Snootalogue.Data;

namespace Snootalogue {
	public class Startup {
		public IConfiguration Configuration { get; set; }

		public Startup(IConfiguration configuration) {
			this.Configuration = configuration;
		}

		// This method gets called by the runtime. Use this method to add services to the container.
		// For more information on how to configure your application, visit https://go.microsoft.com/fwlink/?LinkID=398940
		public void ConfigureServices(IServiceCollection services) {
			services.AddLiveReload();
			services.AddRazorPages().AddRazorRuntimeCompilation();
			services.AddDbContext<SnootalogueContext>(options =>
				options.UseSqlite(Configuration.GetConnectionString("SnootalogueContext"))
			);
		}

		// This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
		public void Configure(IApplicationBuilder app, IWebHostEnvironment env) {
			app.UseLiveReload();

			if (env.IsDevelopment()) {
				app.UseDeveloperExceptionPage();
			}

			app.UseStaticFiles();
			app.UseRouting();

			app.UseEndpoints(endpoints => {
				// endpoints.MapGet("/", async context => {
				// 	await context.Response.WriteAsync("Hello World!");
				// });

				endpoints.MapRazorPages();
			});
		}
	}
}
